`segmented.default` <-
function(obj, seg.Z, psi, control=seg.control(), model=TRUE, ...){
            stop("No default method for segmented")
            }
